import { addSchedule, updateMeetingTask, getUserScheduleInTime, getDeviceBySn } from '../../api/request.js'
import { throttle, getInterTime, getShowTime } from './../../utils/utils.js'
import { checkFullScren } from "../../utils/checkFullScren";
import create from 'dd-store'
import pageStore from '../meetingDetail/store';
create.Page({
  store: pageStore,
  data: {
    $data: null,
    relatedAppPlatform: null,
    // 传给组件list 的所有数据 comListData
    comListData: {
      repeatList: [
        { id: 0, text: '不重复', icon: 'iconicon_cycle', repeatable: 0, recurrenceModel: { model: 'no_repeat' } },
        { id: 1, text: '每天', icon: '', repeatable: 1, recurrenceModel: { model: 'daily', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } },
        { id: 2, text: '每周', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO'] } },
        { id: 3, text: '每周的工作日', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO', 'TU', 'WE', 'TH', 'FR'] } },
        { id: 4, text: '每月', icon: '', repeatable: 1, recurrenceModel: { model: 'absolute_Monthly', daysOfMonth: ['23'], interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } }
      ],
      meetingWayList: [
        // { id: 0, text: 'Webex meeting', imageUrl: '../../assests/Webex.png', meetingWayModel: { model: 'webex' } },
        { id: 0, text: '钉钉', imageUrl: '../../assests/dingding.png', meetingWayModel: { model: 'dingtalk' } },
        { id: 1, text: 'Zoom Meeting', imageUrl: '../../assests/Zoom.png', meetingWayModel: { model: 'zoom' } }
      ],
      comSelectListId: 0,
      meetingWayModelId: null,
      iconType: 'icon'
    },
    // 传给组件 hList 水平排列  所有数据 comHListData
    comHListData: {
      contactData: [
        { id: 0, text: '钉钉联系人', imageUrl: '../../assests/dingContact.png' },
        { id: 1, text: '手动添加邮箱', imageUrl: '../../assests/emailContact.png' }
      ]
    },
    title: ``,
    remark: '',
    isShowRemark: false,
    popup: {
      show: false,
      title: '',
      mask: '',
      type: ''
    },
    showTime: '',

    repeatable: 0,
    recurrenceModel: { model: 'no_repeat' },
    repeatWeek: ['SU', 'MO', 'TU', 'WE', 'TH', 'FR', 'SA'],
    popupTitle: '会议重复',
    popupShow: false,
    comType: '',
    comTimeType: '',
    weekList: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
    week: '',
    conflictPeople: [],
    placeholder: '',
    isIPX: false,
    limitClick: false,
  },
  onLoad(query) {
    if (query && query.sn) {
      getDeviceBySn(query.sn).then(res => {
        if (res.data.code === 0) {
          this.$store.data.locationName = res.data.data.meetingRooomFullName
          this.$store.data.roomId = res.data.data.meetingRoomId
        }
      })
    }
    dd.setNavigationBar({
      title: `创建会议`
    })
    this.setData({
      isIPX: checkFullScren(),
      placeholder: `${getApp().globalData.name}创建的会议`
    })
    this.reset()
  },
  onShow() {
    if (this.$store.data.participatorList.length > 1) {
      this.conflictPeople()
    }
    setTimeout(() => {
      this.update()
    }, 100)
  },
  click() {

    updateMeetingTask()
  },

  // 添加标题
  handleChangeTitle(event) {
    this.setData({
      title: event.detail.value
    })
  },


  // 打开添加描述
  handleOpenRemark() {
    this.setData({
      isShowRemark: true
    })
  },
  // 添加描述
  handleChangeRemark(event) {
    this.setData({
      remark: event.detail.value
    })
  },


  // 跳转选择地点
  goSelectPlace() {
    dd.navigateTo({ url: './../place/place' })
  },
  // 删除地点
  handleDeletePlace() {
    this.$store.data.locationName = ''
    this.$store.data.roomId = ''
    this.update()
  },

  // 选择时间
  handleTime() {
    this.setData({
      popup: {
        show: true,
        title: "选择会议时间",
        mask: true,
        type: 'time'
      }
    })
  },
  // 选择时间点击完成
  onComplete(event) {
    this.$store.data.startTime = `${event.startTime}:00`
    this.$store.data.endTime = `${event.endTime}:00`
    this.update()
    this.setData({
      showTime: getShowTime(this.$store.data.startTime, this.$store.data.endTime)
    })
    this.closePopup()
    this.conflictPeople()
    this.resetRepeatList()

    /* 
    改时间 改掉重复规则
    先选重复规则 再改时间 重复规则也要改变
    暂时修改每周 每月重复问题
     */
    if (this.data.recurrenceModel.model === 'weekly' && this.data.recurrenceModel.weekDayList.length === 1) {
      this.setData({
        recurrenceModel: this.data.comListData.repeatList[2].recurrenceModel
      })
    } else if (this.data.recurrenceModel.model === 'absolute_Monthly') {
      this.setData({
        recurrenceModel: this.data.comListData.repeatList[4].recurrenceModel
      })
    }

  },
  // 关闭popup
  closePopup() {
    this.setData({
      popup: {
        show: false,
        title: "",
        mask: true,
        type: ''
      }
    })
  },

  // 初始化
  reset() {
    this.$store.resetData()
    this.$store.data.startTime = this.getTimes()
    this.$store.data.endTime = this.getTimes(new Date().setMinutes(new Date().getMinutes() + 30))
    this.update()
    this.setData({
      showTime: getShowTime(this.$store.data.startTime, this.$store.data.endTime)
    })
    this.resetRepeatList()
  },



  Complete(data) {
    this.closePop();
  },






  // 跳转下一页
  nextPage(event) {
    switch (event.target.dataset.nextPage) {
      case 'participantsDetail':
        dd.navigateTo({ url: './../participantsDetail/participantsDetail' })
        break
    }
  },
  // 所有的关闭操作
  close(event) {
    switch (event.target.dataset.close) {
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': null,
          meetingWayModel: null
        })
    }
  },

  // 选择循环机制 选择会议方式  选择时间  出现popup弹窗
  showPopup(event) {
    let iconType = ''
    let popupTitle = ''
    switch (event.currentTarget.dataset.type) {
      case 'meetingWayModel':
        iconType = 'image'
        popupTitle = '选择会议方式'
        break
      case 'repeat':
        iconType = 'icon'
        popupTitle = '会议重复'
        break
      case 'participator':
        popupTitle = '选择参会人'
        break

    }
    this.setData({
      popupTitle: popupTitle,
      popupShow: true,
      comType: event.currentTarget.dataset.type,
      'comListData.iconType': iconType
    })

  },
  resetRepeatList() {
    let index = 0
    let repeatList = []
    for (let value of this.data.comListData.repeatList) {
      if (index) {
        value.recurrenceModel.initialTime = this.$store.data.startTime.replace(/\//g, "-").substring(0, 10)
        value.recurrenceModel.terminateTime = this.getTwoYearToday(this.$store.data.startTime)
        if (index === 2) {
          value.recurrenceModel.weekDayList = [this.data.repeatWeek[new Date(this.$store.data.startTime).getDay()]]
        } else if (index === 4) {
          value.recurrenceModel.daysOfMonth = [this.$store.data.startTime.replace(/\//g, "-").substring(8, 10)]
        }
      }
      repeatList.push(value)
      index++
    }
    this.setData({
      'comListData.repeatList': repeatList,
      week: this.data.weekList[new Date(this.$store.data.startTime).getDay()]
    })

  },
  // 选择完comList后的回调
  selectComList(event) {
    switch (this.data.comType) {
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': event.currentTarget.dataset.item.id,
          popupShow: false,
          meetingWayModel: this.data.comListData.meetingWayList[event.currentTarget.dataset.item.id].meetingWayModel
        })
        break;
      case 'repeat':
        this.resetRepeatList()
        this.setData({
          popupShow: false,
          'comListData.comSelectListId': event.currentTarget.dataset.item.id,
          repeatable: event.currentTarget.dataset.item.repeatable,
          recurrenceModel: event.currentTarget.dataset.item.recurrenceModel
        })
        this.conflictPeople()
        break;
    }
  },
  // 选择完水平 HList 的回调
  selectComHList(event) {
    switch (event.currentTarget.dataset.item.id) {
      case 0:
        this.addParticipator()
        this.setData({
          popupShow: false
        })
        break;
      case 1:
        this.setData({
          popupShow: false
        })
        dd.navigateTo({ url: './../outLookContact/outLookContact' })
        break;
    }
  },
  // 获取两年后的今天
  getTwoYearToday(startTime) {
    let date = new Date(startTime)
    date.setYear(date.getFullYear() + 2)
    let year = date.getFullYear();
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1;
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    return year + '-' + month + '-' + day
  },
  // 添加参会人
  handleAddParticipator: throttle(function () {
    const _that = this
    let require = []
    let select = []
    // let outLookConcat = []
    // for (let participator of _that.$store.data.participatorList) {
    //   if (participator.platform === 'outlook') {
    //     outLookConcat.push(participator)
    //   }
    // }
    select = this.$store.data.participatorUserId
    require = [getApp().globalData.userid]
    select = _that.selectedelRequired(require, select).pickedUsers
    dd.complexChoose({
      title: "选择参会人",            //标题
      multiple: true,            //是否多选
      pickedUsers: select, //已选用户    s
      requiredUsers: require,            //必选用户（不可取消选中状态）
      responseUserOnly: true,        //返回人，或者返回人和部门
      success: function (res) {
        let participatorList = []
        let participatorUserId = []
        participatorList.push({ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar, platform: 'dingtalk' })
        participatorUserId.push(getApp().globalData.userid)
        res.users.forEach((item, index) => {
          participatorList.push({ userId: item.userId, username: item.name, headUrl: item.avatar, platform: 'dingtalk' })
          participatorUserId.push(item.userId)
        })
        participatorList = _that.setArrary(participatorList.concat(outLookConcat))
        participatorUserId = [...new Set(participatorUserId)]
        _that.$store.data.participatorList = participatorList
        _that.$store.data.participatorUserId = participatorUserId
        _that.update()
        _that.conflictPeople()
      },
      fail: function (err) {
      }
    })

  }),
  // 已选用户去中去掉必选用户
  selectedelRequired(req, pic) {
    for (let i = 0; i < req.length; i++) {
      for (let m = 0; m < pic.length; m++) {
        if (req[i] == pic[m]) {
          pic.splice(m, 1)
          m--;
        }
      }
    }
    return {
      requiredUsers: req,
      pickedUsers: pic
    }
  },
  // 数组 去重
  setArrary(arr) {
    let containt = {}
    for (let x of arr) {
      containt['id' + x.userId] = x
    }
    return Object.values(containt)
  },

  addSchedule1: throttle(async function () {
    if (this.data.limitClick) {
      return
    }
    this.setData({ limitClick: true });
    dd.showLoading({
      content: '正在创建...',
    });
    let data = {
      title: this.data.title || `${getApp().globalData.name}创建的会议`,
      location: {
        longitude: '10',
        latitude: '10',
        locationName: this.$store.data.locationName
      },
      startTime: this.$store.data.startTime.replace(/\//g, "-"),
      endTime: this.$store.data.endTime.replace(/\//g, "-"),
      meetingRoomId: this.$store.data.roomId,
      scheduleType: this.$store.data.roomId ? 'meeting' : 'common',
      participatorList: !!this.$store.data.participatorList.length ? this.$store.data.participatorList : [{ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar, platform: 'dingtalk' }],
      repeatable: this.data.repeatable,
      remark: this.data.remark,
      recurrenceModel: this.data.recurrenceModel,
      meetingWayModel: { model: null }
    }
    const res = await addSchedule(data).catch(err => {
      this.setData({ limitClick: false });
      dd.hideLoading();
    });
    if (res.data.code === 0) {
      this.$store.data.tabBarIndex = '1';
      this.update();
      if (this.data.repeatable === 0) {
        if (this.$store.addOnceMeeting) {
          await this.$store.addOnceMeeting({
            startTime: new Date(this.$store.data.startTime),
            endTime: new Date(this.$store.data.endTime),
            confirmAttendance: res.data.data.confirmAttendance,
            title: res.data.data.title,
            id: res.data.data.id
          })
        }
      } else {
        if (this.$store.modifyErpeatMeeting) {
          await this.$store.modifyErpeatMeeting()
        }
      }
      this.setData({ limitClick: false });
      dd.hideLoading();
      dd.navigateBack()
    }

  }),
  // 获取时间参数
  getTimes(time = new Date()) {
    let date = getInterTime(new Date(time))
    let year = date.getFullYear()
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    let hour = date.getHours() < 10 ? '0' + date.getHours() : date.getHours()
    let miunutes = date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes()

    return `${year}/${month}/${day} ${hour}:${miunutes}:00`
  },

  // 会议冲突
  conflictPeople() {
    let userIds = []
    for (let value of this.$store.data.participatorList) {
      userIds.push(value.userId)
    }
    let data = {
      startTime: this.$store.data.startTime.replace(/\//g, "-"),
      endTime: this.$store.data.endTime.replace(/\//g, "-"),
      userIds: userIds
    }
    getUserScheduleInTime(data).then(res => {
      let conflictPeople = []
      for (let value in res.data.data) {
        const arr = res.data.data[value].filter(function (item) {
          return item.confirmAttendance === 1
        })
        if (arr.length > 0) {
          conflictPeople.push(value)
        }
      }
      this.setData({
        conflictPeople: conflictPeople
      })
    })
  }
});
