import create from 'dd-store'
import { saveFileInfo, addSchedule, uploadPermissions, previewPermissions, updateMeetingTask } from '../../api/request.js'
import { throttle, debounce } from './../../utils/utils.js'
import pageStore from '../meetingDetail/store';
import { getFileInfo } from '../meetingDetail/uploadFile';

create.Page({
  store: pageStore,
  data: {
    fileInfos: null, //store
    description: '',//store
    id: '',
  },
  onLoad(query) {
    dd.setNavigationBar({
      title: '会议文件'
    });
    // 编辑的时候传了文件ID
    if (query && query.id) {
      this.setData({
        id: query.id
      });
    }
  },
  onShow() {
    this.update()
  },
  inputChange: debounce(function (e) {
    const value = e.detail.value;
    if (value) {
      this.store.data.description = value;
      this.update();
    }
  }, 100),

  //添加会议文件
  async add() {
    const res = await getFileInfo();
    if (res.code === -1) {
      dd.alert({
        content: res.msg
      })
      return
    }
    let data = []
    res.data.map(it => {
      data.push({
        fileId: it.fileId,
        name: it.fileName,
        size: it.fileSize,
        spaceId: it.spaceId,
        mimeType: it.fileType
      })
    })
    this.store.data.fileInfos.push(data)
    this.update();

  },

  // 保存
  saveUpload: throttle(function () {
    const { fileInfos, oldFileInfos, description, oldDescription } = this.store.data;

    if (!fileInfos || (fileInfos && fileInfos.length == 0)) {
      dd.showToast({
        content: '请上传文件'
      })
      return;
    }

    //如果实际没有修改，不生成记录
    if (this.data.id) {
      if (oldFileInfos == JSON.stringify(fileInfos) && description == oldDescription) {
        return dd.navigateBack()
      }
    }

    const data = {
      meetingId: this.data.id,
      platform: 'dingTalk',
      remark: description,
      fileModel: {
        fileList: fileInfos
      }
    }
    updateMeetingTask(data).then(res => {
      console.log(res)
      this.store.data.isNeedReloadList = true;
      this.store.data.fileInfos = []
      this.store.data.description = ''
      this.update();
      dd.navigateBack()
    })
  }, 1000)
});
